set more off
use "${BIO}biomarker_analysis-DR.dta", clear
sample 1
set rmsg on
recode gender (2=0),gen(male)




foreach X in  hdl chol_ratio hbA1c crp_log crp bp_sys bp_dia bmi {
	sum bio_`X'
	gen bio_`X'_sdr = bio_`X'/(`r(max)'-`r(min)')
	sum bio_`X'
	gen bio_`X'_sd = (bio_`X'-`r(mean)')/(`r(sd)')
	sum bio_`X'
}

*** extremely large values of chol-ratio are set to missing
replace bio_chol_ratio = . if bio_chol_ratio >=16


egen bio_check_DR = rownonmiss(bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys)



keep if bio_check_DR ==4
gen dauer = end_age -begin_age
*** drop essential missings***
drop if year ==. | bio_check_DR <=1 | race ==.m | hrs_weight ==. | begin_age >=90 | dauer ==0 | death_ever ==. | hrs_weight ==0




*** comparing variance before and after standardization
sum bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys bio_bp_dia
sum bio_chol_ratio_sdr  bio_hbA1c_sdr bio_crp_log_sdr bio_bp_sys_sdr bio_bp_dia_sdr
sum bio_chol_ratio_sd  bio_hbA1c_sd bio_crp_log_sd bio_bp_sys_sd bio_bp_dia_sd







**** clustering using range (sdr) and standard deviation (sd) standardization
**** generating cluster variables for 3-20 clusters
***** 4 biomarkers
foreach link in  wards  {
	foreach sd in sd {
		cluster `link'linkage bio_chol_ratio_`sd' bio_hbA1c_`sd' bio_crp_log_`sd' bio_bp_sys_`sd',  name(`link'4_`sd') measure(L2)
		*cluster dend, cutnumber(10)
		local link "wards"
		local sd "sd"
		forvalues X = 2/20 {
			cluster generate group_`link'_`sd'_`X' = groups(`X'), name(`link'4_`sd')
			table group_`link'_`sd'_`X', c(m  bio_chol_dum m bio_bp_sys_dum m bio_hbA1c_dum m bio_crp_dum m male)
		}
	}
}

foreach link in wards {
	tab group_`link'_sd_10
}



***************************************
**** SAVE MATRICES AND SCREE PLOTS ****
***************************************

*cluster stop wards5_sd, rule(stepsize) depth(20) matrix(scree5)
cluster stop wards4_sd, rule(stepsize) depth(20) matrix(scree4)

*svmat scree5, names(clus5w)
svmat scree4, names(clus4w)

*gen new_clus5w2 = clus5w2
*replace new_clus5w2 = 499 if clus5w2 >= 500
gen new_clus4w2 = clus4w2
replace new_clus4w2 = 499 if clus4w2 >= 500

twoway  (line new_clus4w2 clus4w1 , sort lcolor(gs0) lwidth(0.7) lpattern(dash)) ,  ///
	   xscale(reverse) $graphstandard legend( order(1 "4 Biomarker") region(lcolor(white)) row(2) ring(0) position(10) bmargin(large)) ///
 yscale(range(0 500)) ylabel(0(100)500, glcolor(none) glpattern(dot)) xtitle("Number of clusters") ytitle("Dissimilarity measure (Eucledian Distance)") xmtick(1(1)20)

graph export "${GRAPHS}cluster_screeplot4.pdf",replace
save "${BIO}clus_new5-DR.dta",replace


