		set more off
		use "${BIO}clus_new5-DR.dta", clear

	*set trace on
	
		
		forvalues X = 2/20 {
			rename group_wards_sd_`X' group_wards4_sd_`X'	
		}
		
		
		
		egen bio_index4 = rowtotal(bio_chol_dum bio_hbA1c_dum bio_crp_dum bio_bp_sys_dum)

		recode bio_index4 (4=3),gen(bio_index4_rec)
		stset end_age if begin_age >=50 [pweight=hrs_weight],  enter(begin_age) failure(death_ever==1) 
		
		**** DEFINE CONTROLS *****
		global controls "i.gender i.race c.begin_age##c.begin_age"
		
		
		***********************
		****  4 biomarkers ****
		***********************
		local clusnum = 20
		foreach bionumb in 4  {
			
			if "`bionumb'" == "4" {
				local biorisk "bio_crp_dum bio_hbA1c_dum bio_chol_dum bio_bp_sys_dum"
				local biocont "bio_chol_ratio_sd bio_hbA1c_sd bio_crp_sd bio_bp_sys_sd"
				local bioint  "i.bio_crp_dum##i.bio_hbA1c_dum##i.bio_hdl_dum##i.bio_bp_sys_dum"
				local colscheme "bar(1, color(gs0)) bar(2, color(gs4)) bar(3, color(gs8)) bar(4, color(gs12))"
			}
			
			local bn = `bionumb'+1
			**** linear prediction from empty model
			stcox   $controls  ,
			predict eta`bionumb'_empty,xb
			**** linear prediction from full model without profiles
			stcox    `bioint' `biocont' $controls,
			predict eta`bionumb'_full,xb
			keep if e(sample)
			
			**** linear prediction from full model without profiles
			stcox  `biorisk' `biocont'  $controls,
			predict eta`bionumb'_all,xb
			
	
			
			
			*****************************************
			***** all predictions separately   ******
			*****************************************
			
			**** index
			stcox  i.bio_index`bionumb' $controls  ,nohr
			predict eta`bionumb'_index,xb
			
	
			**** biomarker risk factors
			stcox  `biorisk' $controls  ,nohr
			predict eta`bionumb'_risk,xb
			

			
			**** biomarker continuous 
			stcox  `biocont'  $controls  ,
			predict eta`bionumb'_bio,xb
			
			
			forvalues clus = 20(-1)3 {
				
					**** identifying clusters that are combined****
					
					local next = `clus'-1
					forvalues V = 1/`next' {
						qui sum group_wards`bionumb'_sd_`clus' if  group_wards4_sd_`next' == `V'
						if `r(min)' != `r(max)' {
							local comb1_`clus' = `r(min)'
							local comb2_`clus' = `r(max)'
						}
					}
					
					
					
					**** estimating mortality prediction RAW
					stcox  b1i.group_wards`bionumb'_sd_`clus' $controls ,
					
					
					**** linear prediction from empty model plus profiles
					predict eta`bionumb'_empty`clus',xb
					

					
					**** estimating mortality prediction controlled for biomarker level and risk factor dummies
					stcox  `biorisk' `biocont' b1i.group_wards`bionumb'_sd_`clus'  $controls ,
					forvalues B = 2/`clus' {
						local HR_cond`B'_`clus' = trim("`: display %10.2f exp(_b[`B'.group_wards`bionumb'_sd_`clus'])'") 
						local hrs   `"`hrs' HR`B': `HR_raw`B'_`clus''/`HR_cond`B'_`clus'';"'
					}
					**** linear prediction from full model plus profiles
					predict eta`bionumb'_all`clus', xb

					
					**** index with profiles and continuous biomarkers
					stcox  i.bio_index`bionumb' `biocont' b1i.group_wards`bionumb'_sd_`clus' $controls  ,nohr
					predict eta`bionumb'_index_cond`clus',xb

					
					
					***********************************************
					***** PLOTTING RESULTS WITH TABLED DATASET ****
					***********************************************
				
					preserve
					table group_wards`bionumb'_sd_`clus', c(mean  bio_chol_ratio_sd  mean bio_hbA1c_sd mean bio_crp_log_sd m bio_bp_sys_sd n bio_bmi_sd) replace
				
					
					
					forvalues F = 1/`bionumb'{
						replace table`F' = 2 if table`F' >2 & table`F' !=.
					}
					
					**** GRAPH WITHOUT TEXT *****
					graph bar table1-table4 , `colscheme' by(group_wards`bionumb'_sd_`clus', ///
					row(1) note("") graphregion(color(white) fcolor(white) icolor(white)))  ///
					legend( order(1 "Cholesterol" 2 "hbA1c" 3 "CRP" 4 "BP (Sys)") region(lcolor(white)) row(1)) ///
					subtitle(,lcolor(white) fcolor(white)) yscale(range(-2 2)) ylabel(-2(0.5)2, glcolor(gs8) glpattern(dot)) ///
					ytitle("Deviation from grand mean (SD)")
					set trace off
					graph export "${GRAPHS}cluster_bio`bionumb'_sd_`clus'_notext.pdf",replace
					
					label define group_wards`bionumb'_sd_`clus' `comb1_`clus'' "combined" `comb2_`clus'' "combined", replace
					label values group_wards`bionumb'_sd_`clus' group_wards`bionumb'_sd_`clus'
					
					
					label drop group_wards`bionumb'_sd_`clus'
					
					
					
					
				restore
			}
			compress
			gen death = death_ever
			saveold "${BIO}clus-eta`bionumb'-DR.dta",replace version(12)
		}
	
