			
			****************************************************
			**** tabelle  with heuristic (risk groups)      ****
			****************************************************
	use "${BIO}clus_new5-new.dta" , clear		
	
	
	

				
				
				*** generate heuristic fromm all possible combinations of risk factors
				gen bio_heu = 1000*bio_chol_dum + 100*bio_hbA1c_dum + 10*bio_crp_dum + bio_bp_sys_dum
				
					
	
	
			local biorisk "bio_chol_dum bio_hbA1c_dum bio_crp_dum bio_bp_sys_dum"
			levelsof bio_heu, local(levels)
			count if bio_heu !=.
			local tot = `r(N)'
			
			mat heu = J(16,6,.)
			local i = 1
			foreach X in `levels' {
				*mat heu[`i',1]=`X'
				local j =1
				foreach Y in `biorisk'	 {
					sum `Y' if bio_heu ==`X'
					mat heu[`i',`j'] = `r(mean)' 
					local ++j
				}
				count if bio_heu == `X' 
				mat heu[`i',5] = `r(N)' 
				mat heu[`i',6] = round(`r(N)'/`tot'*100,.01)
				local ++i
			}
			
			mat colnames  heu = Cholesterol  hbA1c CRP BP(sys) N Prop.
			mat rownames heu = `levels'

			
esttab matrix(heu) using "${TABLES}heuristic-new.rtf", replace

*********************************
***** COMBINE SCREEPLOTS ********
*********************************

use "${BIO}clus_new5-new.dta" , clear
replace clus4w1 = clus4w1-1
twoway (line new_clus4w2 clus4w1 if clus4w1 <20, sort lcolor(gs0) lwidth(0.7) lpattern(solid)) ,  ///
	   xscale(reverse) $graphstandard legend(off)  ///
 yscale(range(0 500)) ylabel(0(100)500, glcolor(none) glpattern(dot)) xtitle("Number of clusters") ytitle("Dissimilarity measure (Euclidean Distance)") xmtick(1(1)20)

graph export "${GRAPHS}cluster_screeplot-DR.pdf",replace


 use "${BIO}clus-max.dta", clear 
 
 twoway (line V1 V2 , sort lcolor(gs0) lwidth(0.7) lpattern(solid)) ,  ///
	   xscale(reverse) $graphstandard legend(off)  ///
 yscale(range(0 0.02)) ylabel(0(0.005)0.02, glcolor(none) glpattern(dot)) xtitle("Number of clusters") ytitle("Decrease in AUC") xmtick(1(1)19)

graph export "${GRAPHS}cluster_screeplot-auc-DR.pdf",replace

*********************************
***** AUC PLOTS          ********
*********************************
set more off, perm

	use "${BIO}AUCs.dta", clear
	gen n = _n
	
	gen All_Cont = All_Risk
	gen All_Profiles = All_Risk
	
	foreach X in Index Risk Cont Profiles Heuristic {
		gen d_`X' = `X'-Empty
		gen marg_`X' = All_`X'-M_`X'
	}
	
	
	stack Empty Empty Empty Empty Empty n  ///
			Index Risk Cont Profiles Heuristic n ///
		   All_Index All_Risk All_Cont All_Profiles All_Heuristic n ///
		   d_Index d_Risk d_Cont d_Profiles d_Heuristic n ///
		   marg_Index marg_Risk marg_Cont marg_Profiles marg_Heuristic n ,  ///
		   into(Index Risk Cont Profiles Heuristic n)
	
	rename _stack delta
	label define delta 1 "Empty" 2 "Level-Only" 3 "Level-All" 4 "Delta" 5 "Marginal"
	label values delta delta
	
	gen average = (Index +Risk+ Cont +Profiles +Heuristic)/5 
	
	stack Index n delta  ///
	      Risk  n delta ///
		  Cont  n delta ///
		  Profiles  n delta ///
		  Heuristic  n delta ///
		  average n delta, ///
		  into(auc n delta)
		  
		  
		rename _stack form
		label define form 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG" 6 "Model-average", replace
		label values form form
		
		
		 label define delta 1 "Empty" 2 "Level-Only" 3 "Level-All" 4 "Delta" 5 "Marginal"
	label values delta delta
	
	graph twoway (line auc n  if delta ==4 & form ==1  ,  color(black)) ///
	             (line auc n  if delta ==4 & form ==2  ,  color(gs6)) ///
				 (line auc n  if delta ==4 & form ==3  ,  color(gs12)) ///
				 (line auc n  if delta ==4 & form ==4  ,  color(black) lstyle(dash)) ///
				 (line auc n  if delta ==4 & form ==5  ,  color(gs6) lstyle(dash)), ///
					 xlabel( 1 "tot_in_all" 2 "tot_out_all" 3 "my_in_all" 4 "my_out_all" 5 "wy_in_all" 6 "wy_out_all" 7 "mo_in_all" 8 "mo_out_all" 9 "wo_in_all" 10 "wo_out_all" ///
               11 "tot_in_cvd" 12 "tot_out_cvd" 13 "my_in_cvd" 14 "my_out_cvd" 15 "wy_in_cvd" 16 "wy_out_cvd" 17 "mo_in_cvd" 18 "mo_out_cvd" 19 "wo_in_cvd" 20 "wo_out_cvd", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot)) ///
					 legend( order(1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8))
	
	gen out = 0
forvalues X = 2(2)20 {
	replace out = 1 if n ==`X'
}		
cap drop group cvd mauc auc_rank
recode n (1 2 11 12 = 1 "Total") (3 4 13 14 = 2 "Men-Young") (5 6 15 16 = 3 "Women-Young") ( 7 8 17 18 = 4 "Men-Old") ( 9 10 19 20 = 5 "Women-Old"), gen(group)
recode n (1/10 = 0) (11/20 = 1), gen(cvd)

egen mauc = mean(auc), by(delta form out)


foreach delta in 4 5 {
	foreach sort in sort fix {

		preserve


		if "`sort'" == "sort" {

				egen auc_rank = rank(auc*-1), by( out cvd group delta) unique

				forvalues X = 1/5 {
					replace group = group +0.5 if group > `X'+(`X')*0.5
					tab group
				}
				replace group = group -0.6+auc_rank*0.2 
				tab group
		}
		else if "`sort'" == "fix" {
			forvalues X = 1/5 {
				replace group = group +0.5 if group > `X'+(`X')*0.5
				tab group
				replace group = group -0.6+`X'*0.2 if form ==`X'
				tab group
			}
		}
		*replace group = group -0.55 if form ==8
		*replace group = group +0.55 if form ==9
		
		

		/*
		
								 (scatter  auc group if  cvd ==0 & form ==1 & delta ==`delta' & out ==0, msym(none) mlab(none) mlabpos(12) mlabcolor (black)) ///
						 (scatter  auc group if  cvd ==0 & form ==2 & delta ==`delta' & out ==0, msym(none) mlab(none) mlabpos(12) mlabcolor (black)) ///
						 (scatter  auc group if  cvd ==0 & form ==3 & delta ==`delta' & out ==0, msym(none) mlab(none) mlabpos(12) mlabcolor (black)) ///
						 (scatter  auc group if  cvd ==0 & form ==4 & delta ==`delta' & out ==0, msym(none) mlab(none) mlabpos(12) mlabcolor (black)) ///
						 (scatter  auc group if  cvd ==0 & form ==5 & delta ==`delta' & out ==0, msym(none) mlab(none) mlabpos(12) mlabcolor (black)) ///
						 
						 */
		
gen aucperc = round(auc,0.001)

			
			graph twoway (bar auc group  if  cvd ==0 & form ==1 & delta ==`delta' & out ==0, barw(0.2) color(black)) ///
						 (bar auc group  if  cvd ==0 & form ==2 & delta ==`delta' & out ==0, barw(0.2) color(gs3)) ///
						 (bar auc group  if  cvd ==0 & form ==3 & delta ==`delta' & out ==0, barw(0.2) color(gs6)) ///
						 (bar auc group  if  cvd ==0 & form ==4 & delta ==`delta' & out ==0, barw(0.2) color(gs9)) ///
						 (bar auc group  if  cvd ==0 & form ==5 & delta ==`delta' & out ==0, barw(0.2) color(gs12) ) /// 
						 , ///
							 xlabel(1 "Total" 2.5 "Men-Young" 4 "Women-Young" 5.5 "Men-Old" 7 "Women-Old"  , angle(45) noticks) ///
							 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot) glwidth(vvthin)) ///
							 legend( order(1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG" ) symxsize(*0.4) size(*0.8)   ///
				region(lcolor(white)) row(1)) xtitle("Functional form") ///
				graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(group_total`sort'`delta', replace)
				 graph export "${GRAPHS}DR-AUC-groups-total-`sort'`delta'.pdf",replace
				 
					graph twoway (bar auc group  if  cvd ==1 & form ==1 & delta ==`delta' & out ==0, barw(0.2) color(black)) ///
								 (bar auc group  if  cvd ==1 & form ==2 & delta ==`delta' & out ==0, barw(0.2) color(gs3)) ///
								 (bar auc group  if  cvd ==1 & form ==3 & delta ==`delta' & out ==0, barw(0.2) color(gs6)) ///
								 (bar auc group  if  cvd ==1 & form ==4 & delta ==`delta' & out ==0, barw(0.2) color(gs9)) ///
								 (bar auc group  if  cvd ==1 & form ==5 & delta ==`delta' & out ==0, barw(0.2) color(gs12)) ///
								 , ///
							 xlabel(1 "Total" 2.5 "Men-Young" 4 "Women-Young" 5.5 "Men-Old" 7 "Women-Old"  , angle(45) noticks) ///
							 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot) glwidth(vvthin)) ///
							 legend( order(1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG" ) symxsize(*0.4) size(*0.8)   ///
				region(lcolor(white)) row(1)) xtitle("Functional form") ///
				graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(group_cvd`sort'`delta', replace)
				 graph export "${GRAPHS}DR-AUC-groups-cvd-`sort'`delta'.pdf",replace
		
		  graph combine group_total`sort'`delta' group_cvd`sort'`delta', graphregion(fcolor(white) lcolor(white)) xsize(7.5)
		graph export "${GRAPHS}DR-AUC-groups-comb`sort'`delta'.pdf",replace

		restore

	}
}

drop if form ==6

	replace form = form -0.2 if delta ==4
	replace form = form +0.2 if delta ==5
	
	graph twoway (bar auc form  if n==6 & delta ==4  , barw(0.4) color(black)) ///
	             (bar auc form  if n==6 & delta ==5  , barw(0.4) color(gs6)) , ///
					 xlabel( 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(none) glpattern(dot)) ///
					 legend( order(1 "Alone" 2 "Marginal") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) xtitle("Functional form") ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8))
		 graph export "${GRAPHS}DR-AUC-one-dataset.pdf",replace

		 
	replace form = form +0.2 if delta ==4
	replace form = form -0.2 if delta ==5		 
	
	replace form = form -0.2 if out ==0
	replace form = form +0.2 if out ==1
		
		
		**** AVERAGED ACROSS ALL MODEL SPECIFICATIONS ****
	graph twoway (bar mauc form  if  delta ==4 & out ==0  , barw(0.4) color(black)) ///
	             (bar mauc form  if  delta ==4 & out ==1 , barw(0.4) color(gs6)) , ///
					 xlabel( 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot)) ///
					 legend( order(1 "CRP >=10 included" 2 "CRP >=10 excluded") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) xtitle("Functional form") ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(out_delta, replace)

 graph export "${GRAPHS}DR-AUC-DELTA-out-comparison.pdf",replace
 
 	 
	 gen maucperc =round(mauc,0.001)
	 
	graph twoway (bar mauc form  if  delta ==5 & out ==0  , barw(0.4) color(black)) ///
	             (bar mauc form  if  delta ==5 & out ==1 , barw(0.4) color(gs6)),  ///
					 xlabel( 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot)) ///
					 legend( order(1 "CRP >=10 included" 2 "CRP >=10 excluded") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) xtitle("Functional form") ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(out_marg, replace)

 graph export "${GRAPHS}DR-AUC-MARGINAL-out-comparison.pdf",replace
 
 	
	 graph combine out_delta out_marg, graphregion(fcolor(white) lcolor(white)) xsize(7.5)
	graph export "${GRAPHS}DR-AUC-COMB-out-comparison.pdf",replace
  
  **** TOTAL SAMPLE ALL-CAUSE MORTALITY ******
  
  	graph twoway (bar auc form  if  delta ==4 & out ==0 & n ==1 , barw(0.4) color(black)) ///
	             (bar auc form  if  delta ==4 & out ==1 & n ==2, barw(0.4) color(gs6)) , ///
					 xlabel( 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot)) ///
					 legend( order(1 "CRP >=10 included" 2 "CRP >=10 excluded") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) xtitle("Functional form") ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(out_delta, replace)

 graph export "${GRAPHS}DR-AUC-DELTA-out-comparison-tot.pdf",replace
 
 	 

	 
	graph twoway (bar auc form  if  delta ==5 & out ==0  & n==1, barw(0.4) color(black)) ///
	             (bar auc form  if  delta ==5 & out ==1  & n==2, barw(0.4) color(gs6)),  ///
					 xlabel( 1 "Index" 2 "RF" 3 "Continuous" 4 "RP" 5 "RG", angle(45) noticks) ///
					 yscale(range(0.0 0.1)) ylabel(0.0(0.01)0.1, glcolor(gs8) glpattern(dot)) ///
					 legend( order(1 "CRP >=10 included" 2 "CRP >=10 excluded") symxsize(*0.4) size(*0.8)   ///
		region(lcolor(white)) row(1)) xtitle("Functional form") ///
		graphregion(color(white) fcolor(white) icolor(white))  ytitle("AUC", height(8)) name(out_marg, replace)

 graph export "${GRAPHS}DR-AUC-MARGINAL-out-comparison-tot.pdf",replace

 	
	 graph combine out_delta out_marg, graphregion(fcolor(white) lcolor(white)) xsize(7.5)
	graph export "${GRAPHS}DR-AUC-COMB-out-comparison-tot.pdf",replace

*********************************
***** SUMMARY STATISTICS ********
*********************************


use "${BIO}DR-biomarker-post-9.dta", clear

tab race,gen(racedum)
tab gender,gen(gender)

recode gender (2=0),gen(male)
				gen bio_crp = exp(bio_crp_log)
				recode bio_crp (min/2.9999 =0 "low") (3/max =1 "high"),gen(bio_crp_dum)
				label variable bio_crp_dum "High CRP (>=3.0 ug/mL)"
				recode bio_hbA1c (min/6.399999999999 =0 "low") (6.4/max =1 "high"),gen(bio_hbA1c_dum)
				label variable bio_hbA1c_dum "High hbA1c (>=6.4%)"
				recode bio_bp_sys (min/139=0) (139.0000005/max=1), gen(bio_bp_sys_dum)
				label variable bio_bp_sys_dum "High risk systolic BP (>139)"
				recode bio_chol_ratio  (min/4.99999999 =0) (5/max = 1) if gender ==1,gen(bio_chol_dum)
				recode bio_chol_ratio  (min/4.49999999 =0) (4.5/max = 1) if gender ==2,gen(bio_chol_dum2)
				replace bio_chol_dum = bio_chol_dum2 if gender ==2
				drop bio_chol_dum2
				label variable bio_chol_dum "High ratio of TC to HDL (>5)"

				
			**** MISSING VALUES
cap program drop addmiss
program addmiss
syntax  [if]
marksample touse
		count if `touse'
		mat a = colsof(e(count))
		mat num = J(1,a[1,1],`r(N)')
		mat miss = num-e(count)
		estadd matrix miss
end		
				

 estpost su  begin_age racedum1 racedum2 racedum3 gender1     /*
    */ bio_chol_dum bio_hbA1c_dum bio_crp_dum bio_bp_sys_dum /*
	*/ bio_chol_ratio bio_hbA1c bio_crp bio_bp_sys if _mi_m ==0
addmiss if _mi_m ==0
	
	est store trajec, title("Summary statistics") 
 esttab  trajec using "${TABLES}sample_stats_bio-cvd-DR-new.rtf", rtf cells("mean(fmt(%06.2fc)) sd min max miss(fmt(%5.0f))")  replace/*
    */ compress  mtitles title("Table 1: Summary statistics") stats(N, fmt(0) labels("Observations"))   label  /*
	*/  mlabels(,none) nonumbers collabels("Mean" "SD" "Minimum" "Maximum" "Missings")
