#######################################################################
################ FUNCTIONS FOR AUROC SURVIVAL ANALYSES ################
#######################################################################

##############################################
###### load data from Stata analysis #########
##############################################

load.data <- function(name){
  setwd(bio.path)
  hrs.data <-  read.dta(paste0("clus-eta4-",name,"-DR.dta"),convert.factors = FALSE)
  attach(hrs.data)
  
  
  
  etas <- list(eta_empty,
               eta_index,eta_risk,eta_cont,eta_empty9,eta_heu,
               eta_minus_index,eta_minus_risk,eta_minus_cont,eta_minus_9,eta_minus_index,
               eta_all_index,eta_all_risk,eta_all_heu)
  names(etas) <- c("Empty",
                   "Index","Risk","Cont","Profiles","Heuristic",
                   "M_Index","M_Risk","M_Cont","M_Profiles","M_Heuristic",
                   "All_Index","All_Risk","All_Heuristic")
  detach(hrs.data)
  return(etas)  
}




###graph.it begin
graph.it <- function(auc.list,auc.name,makeplot=FALSE) {
  calc.auc <- function(mark) {
    test <- risksetAUC(Stime=hrs.data$end_age,
               status=hrs.data$death,
               entry= hrs.data$begin_age,
               marker = mark,
               method="Cox",
               tmax=80,span = 1, plot=FALSE)
  }
  
  
  plot.auc <- function(auc.object,i,auc.ob) {
    
    pdf(paste0(eta.num,"-AUC-",auc.name,i,".pdf"),width=16,height=9,pointsize=12*sc)
    mar.default <- c(5,4,4,2) + 0.1
    par(mar = mar.default + c(0, 1.2, 0, 0)) 
    xrange <- range(c(55,80))
    yrange <- range(c(0.5,0.7))
    plot(xrange, yrange, type="n", xlab="Age (years)",
         ylab="AUC",cex.lab=3, cex.axis=2, cex.main=2, cex.sub=2 )
    
    abline(0.5,0)
    legend(xrange[1], yrange[2], cex=1.8,ncol=2, col=(1:length(auc.age)),
           lwd=6, lty=c(1,2,3,4), seg.len=4,
           legend=names(auc.age[c(1:i)]), bty="n") 
    for (step in 1:i){
      lines(auc.ob[[step]]$utimes,auc.ob[[step]]$AUC,lwd=6,
            lty=linetypes[[step]],col=step)
    }
    dev.off()
  }
  
  if (auc.name!="Profiles"){
    hrs.data <-  read.dta(paste0(bio.path,"clus-eta4-",auc.name,"-DR.dta"),convert.factors = FALSE)
  }
  else if  (auc.name=="Profiles"){
    hrs.data <-  read.dta(paste0(bio.path,"clus-eta4-DR.dta"),convert.factors = FALSE)
  }
    eta.num <- deparse(substitute(auc.list))
    auc.age <- lapply(auc.list, FUN=calc.auc)
    cols <- sapply(seq(0,1,1/(length(auc.age)+1)),function(c){rgb(c, c, c)})
    palette(cols)
    if (makeplot==TRUE){
      lapply(seq_along(auc.age), function(i){plot.auc(auc.age[[i]], i,auc.age)})
    }
    auc.prof <- mean(auc.age[[1]]$AUC)
    auc.prof2 <- 0
    for (step in 2:length(auc.age)){
      auc.prof <- c(auc.prof,mean(auc.age[[step]]$AUC))
      auc.prof2 <- c(auc.prof2,mean(auc.age[[step]]$AUC)-mean(auc.age[[step-1]]$AUC))
      #print(auc.prof)
    }
    
    
    cols <- sapply(seq(0,1,1/(length(auc.age)+1)),function(c){rgb(c, c, c)})
    palette(cols)
    
    
    
    lapply(seq_along(auc.age), function(i){plot.auc(auc.age[[i]], i,auc.age)})
    
    library(foreign)
    write.dta(as.data.frame(matrix(c(auc.prof2,1:length(auc.age)),nrow=19,ncol=2,byrow = FALSE)), paste0(bio.path,"clus-max.dta"))
    return(auc.prof)
  
  ###graph.it end
}
