*********************************
* Hannes Kröger					*
* data file 2016/03/03		*
* 								*
* BIO-CVD      datafile for     *
* gettin biomarker data from HRS*
* 				   				*
*********************************


set more off

local biolist ""

foreach X in 06 08 10 12 {
	use "${sens}BIOMK`X'BL_R.dta", clear
		foreach var of varlist _all {
		if "`var'" != "PN" & "`var'" != "HHID" {
			local nv = substr("`var'",2,.)
			rename `var' `nv'20`X'
			if regexm("`lablist'","`nv'") == 0 {
				local lablist "`lablist' `nv'"
			}
		}
	}
	save "${sens}bio`X'.dta", replace
}

dis "`lablist'"
	
use "${sens}bio06.dta", clear

rename HDl_ADJ2006 HDL_ADJ2006
rename HDlBIOS2006 HDLBIOS2006

foreach X in 08 10 12 {
	merge 1:1 HHID PN using "${sens}bio`X'.dta", nogenerate
}

foreach v of var*{
        local l`v' : variable label `v'
 }

reshape long `lablist', i(HHID PN) j(year)

/*
For all years dried blood spot (DBS) samples have been assayed for 5 biomarkers:
a. Total and HDL cholesterol, indicators of lipid levels
b. Glycosylated hemoglobin (HbA1c) – an indicator of glycemic control over the past 2-3 months
c. C-reactive protein (CRP), a general marker of systemic inflammation
d. Cystatin C, an indicator of kidney functioning.
*/


rename  A1C_ADJ  bio_hbA1c
label variable bio_hbA1c "HbA1c (%) - NHANES"
move bio_hbA1c year
rename  HDL_ADJ  bio_hdl
move bio_hdl year
label variable bio_hdl "HDL (mg/dL) - NHANES"
rename  TC_ADJ	 bio_tc
move bio_tc year 
label variable bio_tc "Total Cholesterol (mg/dL) - NHANES"
rename  CRP_ADJ	 bio_crp
move bio_crp year
label variable bio_crp "CRP (ug/mL) - NHANES"
rename  CYSC_ADJ bio_cystatin
label variable bio_cystatin "Cystatin C (mg/L) - NHANES"
move bio_cystatin year


keep bio_* HHID PN year BIOWGTR




*** generate combined HHID and PN like in the RAND file
destring HHID, replace
destring PN, replace
gen double hhidpn = 1000*HHID+PN
rename year syear
compress
save "${sens}hrs_biomarker.dta", replace
