*********************************
* Hannes Kröger					*
* data file 2016/03/03		*
* 								*
* BIO-CVD      datafile for     *
* gettin education and mortality*
* 				   				*
*********************************

set more off
use hhidpn rahhidpn hhid r*iwendy r*iwendm r*iwstat raracem radyear ragender radmonth racohbyr rabyear rabmonth r*edegrm r*edyrs r*educ /*
*/ r*strok* r*heart* r*diab* r*hibp* r*cancr* r*lung* r*imrc r*dlrc r*ser7 ///
   s*imrc s*dlrc s*ser7 s*educ s*edyrs s*byear s*bmonth s*gender using "${HRS}rndhrs_p.dta", clear

local i = 1992

forvalues X = 1/12 {
	foreach Y in  iwendy iwendm iwstat strok heart diab hibp cancr lung  stroks hearts diabs strokq heartq diabq hibpq cancrq lungq imrc dlrc ser7 {
		cap rename r`X'`Y' `Y'`i'
	}
	local i = `i' +2
}
local i = 1992
forvalues X = 1/12 {
	foreach Y in  educ edyrs imrc dlrc ser7 bmonth byear gender {
		cap rename s`X'`Y' s`Y'`i'
	}
	local i = `i' +2
}

rename raeduc educ
rename raedegrm edegrm
rename raedyrs edyrs		
		
keep hhidpn edegrm* edyrs* educ* iwendy* iwendm* radyear radmonth racohbyr rabyear rabmonth iwstat* ragender strok* heart* diab* hibp* cancr* lung*  ///
     seduc* sedyrs* imrc* dlrc* ser7* simrc* sdlrc* sser7* sbmonth* sbyear* sgender* raracem 

reshape long  iwendy iwendm iwstat strok heart diab hibp cancr lung  strokq heartq diabq hibpq cancrq lungq imrc dlrc ser7 ///
              seduc sedyrs simrc sdlrc sser7 sbmonth sbyear sgender stroks hearts diabs, i(hhidpn) j(year)

label values edyrs EDYRS
label values edegrm EDEGRM
label values educ EDUC
rename ragender gender

label variable edyrs  "Years of education"
label variable edegrm "Highest degree (masked)"
label variable educ   "Education (categories)"


rename year syear
rename iwendy year

merge m:1 hhidpn  using "${HRS}hrs_exit.dta", keep(1  3) nogenerate




cap drop death*
gen death_ever = 1 if (radyear <. & radyear >2006) 

replace year = syear if year ==.
xtset hhidpn syear
gen death = 1 if radyear ==year | radyear == (year-1) & radyear >2006
gen age = ((year-rabyear)*12 + iwendm-rabmonth )/12
replace age =  ((year-rabyear)*12 + 6)/12 if iwendm ==.
gen sage = ((year-sbyear)*12 + iwendm-sbmonth )/12
replace sage =  ((year-sbyear)*12 + 6)/12 if iwendm ==.
**** set to missing if dead and just keep those who are still alive based on iwstat

egen bla = max(year) if iwstat ==1 | iwstat ==4,by(hhidpn)
egen hrs_myear =max(bla),by(hhidpn)
drop bla


replace age =. if iwstat != 1 & iwstat !=4
cap drop maxage
egen maxage = max(age),by(hhidpn)
gen death_age = ((radyear-rabyear)*12 + radmonth-rabmonth )/12

gen time = maxage
replace time = death_age
keep if syear >=2006 & radyear >2006

gen cog = imrc + dlrc
gen scog = simrc + sdlrc

rename raracem race
*** gnerate per household maximum level of education and cognitive score
foreach X in cog educ edyrs {
	egen max_`X' = rowmax(`X' s`X')
}


compress

save "${HRS}education.dta", replace
 
 set more off
use "${HRS}education.dta", clear

	merge 1:1 hhidpn syear using "${sens}hrs_biomarker.dta", keep(1 2 3) nogenerate
	merge 1:1 hhidpn syear using "${HRS}hrs_physical.dta",   keep(1 2 3) nogenerate
	*merge 1:1 hhidpn syear using "${HRS}hrs_DDs.dta",   keep(1 2 3) nogenerate
	
	bysort hhidpn: gen n =_n
	*** variable indicating presence of biomarkers
	egen bio_check = rownonmiss(bio_cystatin bio_crp bio_hbA1c bio_tc bio_hdl)
	
	forvalues X = 2006/2012 {
		cap drop bla
		gen bla = bio_check if syear ==`X'
		egen bio_check`X' = mean(bla),by(hhidpn)
	}
	cap drop bla
	gen bla =.
	forvalues X = 2010(-2)2006 {
		replace bla =year if bio_check`X' >=1 & syear == `X'
	}
	
	egen begin = min(bla),by(hhidpn)
	*replace begin =2008 if bio_check2008 >=1
	*replace begin =2010 if bio_check2010 >=1 & bio_check2008 ==0 & bio_check2006 ==0
	
	cap drop bla
	egen bla = max(year) if iwstat ==0 | iwstat ==1 | iwstat ==4,by(hhidpn)
	egen end = max(bla), by(hhidpn)
	replace end = radyear if radyear <.

	gen end_age = end-rabyear
	gen begin_age= begin-rabyear
    recode death_ever .=0
	gen study =2
	keep if hrs_myear >=2006
save "${TEMP}hrs_combined.dta",replace	

		
	
	
	
