
************************************************
****** MULTIPLE IMPUTATION FOR BIO-CVD *********
************************************************

set more off
use "${BIO}biomarker_analysis-DR.dta", clear

	egen bio_check_DR = rownonmiss(bio_chol_ratio bio_hbA1c bio_crp bio_bp_sys)
		gen dauer = end_age -begin_age
*** drop essential missings***
drop if year ==. | bio_check_DR <=1 | race ==.m | hrs_weight ==. | begin_age >=90 | dauer ==0 | death_ever ==. | hrs_weight ==0

recode gender (2=0),gen(male)
	merge 1:1 newid using "${BIO}clus_new5-DR.dta", keepusing(*wards*) keep(3)
	
	


	
**** keep only those variables which are to be imputed ***
keep newid gender race year	bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys ///
     death_ever2 begin_age end_age hrs_weight group_wards_sd_9 ///
	 bio_gs bio_bmi bio_pulse bio_check_DR dauer
	 
sum newid gender race year	bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys ///
     death_ever2 begin_age end_age hrs_weight group_wards_sd_9 ///
	 bio_gs bio_bmi  bio_pulse
	







recode begin_age (50/69 = 1 "50-69") (70/89 = 2 "70-89"),gen(age_cat)

	 
*** auxilary variables: bio_gs bio_bmi  bio_pulse
	
	xtset, clear
 mi set mlong
 mi register imputed bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys ///
        group_wards_sd_9 ///
	 bio_gs bio_bmi bio_pulse
 mi register regular death_ever2 dauer begin_age end_age gender race year hrs_weight age_cat

 
 
 compress
save "${BIO}DR-biomarker-pre-MI-DR.dta", replace
save "${BIO}DR-biomarker-post-DR.dta", replace

set seed 789949833
set matsize 5000
forvalues X = 1/40 {
	use "${BIO}DR-biomarker-post-DR.dta", clear

		*** sometimes the mlogit model does not converge ***
	cap mi impute chained (regress) bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys bio_gs bio_bmi  bio_pulse /*
	*/ (mlogit, iterate(100))    group_wards_sd_9 /*
	 */ =  c.begin_age##c.begin_age c.dauer i.death_ever2 i.race [pweight=hrs_weight],   force augment  dots  add(1) by(gender age_cat)
	
	save "${BIO}DR-biomarker-post-DR.dta", replace
 }
 
 
 
 
 ***** MI if CRP >10 is excluded from the analyses ******
set more off
set seed 88997766
 use "${BIO}DR-biomarker-pre-MI-DR.dta", clear
 
 drop if exp(bio_crp) >=10
 
 save "${BIO}DR-biomarker-post-DRout.dta", replace

set seed 789949833
set matsize 5000
forvalues X = 1/40 {
	use "${BIO}DR-biomarker-post-DRout.dta", clear

		*** sometimes the mlogit model does not converge ***
	cap mi impute chained (regress) bio_chol_ratio bio_hbA1c bio_crp_log bio_bp_sys bio_gs bio_bmi  bio_pulse /*
	*/ (mlogit, iterate(120))    group_wards_sd_9 /*
	 */ =  c.begin_age##c.begin_age c.dauer i.death_ever2 i.race [pweight=hrs_weight],   force augment  dots  add(1) by(gender age_cat)
	
	save "${BIO}DR-biomarker-post-DRout.dta", replace
 }
 
 
 
 
