*********************************
* Hannes Kröger					*
* program file 2018/03/05		    *
* 								*
* BIO-CVD       programfile for  *
* data preparation  *
* 				   				*
*********************************


*** program that creates cut-offs
cap program drop bio_cut_off
program bio_cut_off

	recode bio_crp (min/2.9999 =0 "low") (3/max =1 "high"),gen(bio_crp_dum)
	label variable bio_crp_dum "High CRP (>=3.0 ug/mL)"
	recode bio_hbA1c (min/6.39999 =0 "low") (6.4/max =1 "high"),gen(bio_hbA1c_dum)
	label variable bio_hbA1c_dum "High hbA1c (>=6.4%)"
	recode bio_tc (min/239.9999 =0 "low") (240/max =1 "high"),gen(bio_tc_dum)
	label variable bio_tc_dum "High risk cholesterol (>=240 mg/dL)"
	recode bio_hdl (min/39.9999 =1 "high") (40/max =0 "low"),gen(bio_hdl_dum)
	label variable bio_hdl_dum "High risk HDL cholesterol (<40 mg/dL)"
	cap recode bio_cystatin (min/1.55 =0 "low") (1.550001/max =1 "high"),gen(bio_cystatin_dum)
	cap label variable bio_cystatin_dum "High Cystatin C (>1.55 (mg/L))"


	*** blood pressure
	recode bio_bp_sys (min/139=0) (139.0000005/max=1), gen(bio_bp_sys_dum)
	label variable bio_bp_sys_dum "High risk systolic BP (>139)"
	recode bio_bp_dia (min/89=0) (89.0000005/max=1), gen(bio_bp_dia_dum)
	label variable bio_bp_dia_dum "High risk diastolic BP (>89)"
	
	gen bio_bp_sys_cat = bio_bp_sys_dum
	cap replace bio_bp_sys_cat =2 if bio_bp_warning ==1
	
	
	*** BMI ***
	recode bio_bmi (min/29.99999=0) (30/max=1), gen(bio_bmi_dum)
	recode bio_bmi (min/34.99999=0) (35/max=1), gen(bio_bmi_dum2)
	recode bio_bmi (min/29.99999=0) (30/34.999999=1) (35/39.9999=2) (40/max=3), gen(bio_bmi_cat)



	****** ELSA RECODES ****
	*bio_sysval bio_diaval bio_trig bio_ldl


	gen bio_chol_ratio = bio_tc/bio_hdl
	recode bio_chol_ratio  (min/4.9999999 =0) (5/max = 1) if gender ==1,gen(bio_chol_dum)
	recode bio_chol_ratio  (min/4.49999999 =0) (4.5/max = 1) if gender ==2,gen(bio_chol_dum2)
	replace bio_chol_dum = bio_chol_dum2 if gender ==2
	drop bio_chol_dum2
	label variable bio_chol_dum "High ratio of TC to HDL (>5)"
	
	gen bio_crp_log = ln(bio_crp)

end


**********************************************
**** PROGRAM TO SAVE DISSIMILARITY STEPS  ****
**** INTO A MATRIX TO PLOT A SCREE        ****
**** AND EVALUATE THE ELBOW CRITERION     ****
**********************************************




cap program drop clstop_stepsize
program clstop_stepsize, sortpreserve rclass
	version 14.1
	syntax anything(name=clname) [, Depth(integer -1) matrix(string)]
	cluster query `clname'
	if "`r(type)'" != "hierarchical" {
	di as error ///
	"rule(stepsize) only allowed with hierarchical clustering"
	exit 198
	}
	if "`r(pseudo_heightvar)'" != "" {
	di as error "dendrogram reversals encountered"
	exit 198
	}
	local hgtvar `r(heightvar)'
	if `"`r(similarity)'"' != "" {
	sort `hgtvar'
	local negsign "-"
	}
	else if `"`r(dissimilarity)'"' != "" {
	gsort -`hgtvar'
	}
	else {
	di as error "dissimilarity or similarity not set"
	exit 198
	}
	quietly count if !missing(`hgtvar')
	local depth = cond(`depth'<=1, r(N), min(`depth',r(N)))
	tempvar diff
	qui gen double `diff'=`negsign'(`hgtvar'-`hgtvar'[_n+1]) if _n<`depth'
	di
	di as txt "Depth" _col(10) "Stepsize"
	di as txt "{hline 17}"
	mat `matrix' = J(`depth'-1,2,.)
	forvalues i = 1/`= `depth'-1' {
		local j = `i' + 1
		di as res `j' _col(10) %8.0g `diff'[`i']
		return scalar stepsize_`j' = `diff'[`i']
		mat `matrix'[`i',1] = `j'
		mat `matrix'[`i',2] = `diff'[`i']
	}
	return local rule "stepsize"
end




